@@ -3,7 +3,7 @@
  * and exported functions for
  * Broadcom 802.11abg Networking Device Driver
  *
- * Copyright 2008, Broadcom Corporation
+ * Copyright (C) 2010, Broadcom Corporation
  * All Rights Reserved.
  * 
  * THIS SOFTWARE IS OFFERED "AS IS", AND BROADCOM GRANTS NO WARRANTIES OF ANY
@@ -11,7 +11,7 @@
  * SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
  * FOR A SPECIFIC PURPOSE OR NONINFRINGEMENT CONCERNING THIS SOFTWARE.
  *
- * $Id: wlc_key.h,v 1.44.2.5 2008/08/22 00:37:51 Exp $
+ * $Id: wlc_key.h,v 1.64.8.4 2010/06/09 02:22:27 Exp $
  */
 
 #ifndef _wlc_key_h_
@@ -22,13 +22,19 @@ typedef struct wsec_iv {
 	uint16		lo;	
 } wsec_iv_t;
 
+#if defined(MFP)
+#define WLC_NUMRXIVS	17	
+#define WLC_MFP_IVIDX	16	
+#else
 #define WLC_NUMRXIVS	16	
+#endif 
 
 typedef struct wsec_key {
 	struct ether_addr ea;		
 	uint8		idx;		
 	uint8		id;		
 	uint8		algo;		
+	uint8		rcmta;		
 	uint16		flags;		
 	uint8 		algo_hw;	
 	uint8 		aes_mode;	
@@ -40,6 +46,9 @@ typedef struct wsec_key {
 	wsec_iv_t	rxiv[WLC_NUMRXIVS];		
 	wsec_iv_t	txiv;		
 
+#ifdef GTK_RESET
+	bool		gtk_plumbed;
+#endif 
 } wsec_key_t;
 
 #endif 
